"""Logging contains the AxiomHandler and related methods to do with logging."""
from logging import Handler, NOTSET, getLogger, WARNING
from .client import Client


class AxiomHandler(Handler):
    """A logging handler that sends logs to Axiom."""

    client: Client
    dataset: str

    def __init__(self, client: Client, dataset: str, level=NOTSET):
        Handler.__init__(self, level)
        # set urllib3 logging level to warning, check:
        # https://github.com/axiomhq/axiom-py/issues/23
        # This is a temp solution that would stop requests
        # library from flooding the logs with debug messages
        getLogger("urllib3").setLevel(WARNING)
        self.client = client
        self.dataset = dataset

    def emit(self, record):
        # FIXME: Don't do an ingest call for every event
        self.client.ingest_events(self.dataset, [record.__dict__])



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['axiom', 'axiom.query']

package_data = \
{'': ['*']}

install_requires = \
['dacite>=1.6.0,<2.0.0',
 'iso8601>=1.0.2,<2.0.0',
 'ndjson>=0.3.1,<0.4.0',
 'pyhumps>=1.6.1,<2.0.0',
 'requests-toolbelt>=0.9.1,<0.10.0',
 'requests>=2.25.1,<3.0.0',
 'rfc3339>=6.2,<7.0',
 'ujson>=5.2.0,<6.0.0']

setup_kwargs = {
    'name': 'axiom-py',
    'version': '0.1.0b5',
    'description': 'Axiom API Python bindings.',
    'long_description': None,
    'author': 'Axiom, Inc.',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
